<?php

function ripple_page_lists() {
    $pages = get_pages();
    $page_list = array();
    $page_list[0] = __('Select Page', 'ripple');
    foreach ($pages as $page) :
        $page_list[$page->ID] = $page->post_title;
    endforeach;
    return $page_list;
}

function ripple_category_lists() {
    $categories = get_categories(
            array(
                'hide_empty' => 0,
                'exclude' => 1
            )
    );

    $category_list = array();
    $category_list[0] = __('Select Category', 'ripple');
    foreach ($categories as $category) :
        $category_list[$category->term_id] = $category->name;
    endforeach;
    return $category_list;
}

function ripple_breadcrumb_cb() {
    global $post;
    $showOnHome = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show

    $delimiter = '&gt;';

    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $homeLink = esc_url( home_url() );

    if (is_home() || is_front_page()) {

        if ($showOnHome == 1)
            echo '<div id="ripple-breadcrumb"><a href="' . esc_url($homeLink) . '">' . __('خانه', 'ripple') . '</a></div></div>';
    } else {

        echo '<div id="ripple-breadcrumb"><a href="' . esc_url($homeLink) . '">' . __('خانه', 'ripple') . '</a> ' . esc_attr($delimiter) . ' ';

        if (is_category()) {
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0)
                echo get_category_parents($thisCat->parent, TRUE, ' ' . esc_attr($delimiter) . ' ');
            echo '<span class="current">' . __('Archive by category','ripple').' "' . single_cat_title('', false) . '"' . '</span>';
        } elseif (is_search()) {
            echo '<span class="current">' . __('Search results for','ripple'). '"' . get_search_query() . '"' . '</span>';
        } elseif (is_day()) {
            echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . absint(get_the_time('Y')) . '</a> ' . esc_attr($delimiter) . ' ';
            echo '<a href="' . esc_url(get_month_link(get_the_time('Y')), absint(get_the_time('m'))) . '">' . absint(get_the_time('F')) . '</a> ' . esc_attr($delimiter) . ' ';
            echo '<span class="current">' . absint(get_the_time('d')) . '</span>';
        } elseif (is_month()) {
            echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . absint(get_the_time('Y')) . '</a> ' . esc_attr($delimiter) . ' ';
            echo '<span class="current">' . absint(get_the_time('F')) . '</span>';
        } elseif (is_year()) {
            echo '<span class="current">' . absint(get_the_time('Y')) . '</span>';
        } elseif (is_single() && !is_attachment()) {
            if (get_post_type() != 'post') {
                $post_type = get_post_type_object(get_post_type());
                $slug = $post_type->rewrite;
                echo '<a href="' . esc_url($homeLink) . '/' . esc_attr($slug['slug']) . '/">' . esc_attr($post_type->labels->singular_name) . '</a>';
                if ($showCurrent == 1)
                    echo ' ' . esc_attr($delimiter) . ' ' . '<span class="current">' . esc_attr(get_the_title()) . '</span>';
            } else {
                $cat = get_the_category();
                $cat = $cat[0];
                $cats = get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
                if ($showCurrent == 0)
                    $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
                echo ripple_sanitize_bradcrumb($cats);
                if ($showCurrent == 1)
                    echo '<span class="current">' . esc_attr(get_the_title()) . '</span>';
            }
        } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
            $post_type = get_post_type_object(get_post_type());
            echo '<span class="current">' . esc_attr($post_type->labels->singular_name) . '</span>';
        } elseif (is_attachment()) {
            if ($showCurrent == 1) echo ' ' . '<span class="current">' . esc_attr(get_the_title()) . '</span>';
        } elseif (is_page() && !$post->post_parent) {
            if ($showCurrent == 1)
                echo '<span class="current">' . esc_attr(get_the_title()) . '</span>';
        } elseif (is_page() && $post->post_parent) {
            $parent_id = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
                $parent_id = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            for ($i = 0; $i < count($breadcrumbs); $i++) {
                echo esc_attr($breadcrumbs[$i]);
                if ($i != count($breadcrumbs) - 1)
                    echo ' ' . esc_attr($delimiter) . ' ';
            }
            if ($showCurrent == 1)
                echo ' ' . esc_attr($delimiter) . ' ' . '<span class="current">' . esc_attr(get_the_title()) . '</span>';
        } elseif (is_tag()) {
            echo '<span class="current">' . __('Posts tagged','ripple').' "' . single_tag_title('', false) . '"' . '</span>';
        } elseif (is_author()) {
            global $author;
            $userdata = get_userdata($author);
            echo '<span class="current">' . __('Articles posted by ','ripple'). esc_attr($userdata->display_name) . '</span>';
        } elseif (is_404()) {
            echo '<span class="current">' . 'Error 404' . '</span>';
        }

        if (get_query_var('paged')) {
            if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
                echo ' (';
            echo __('Page', 'ripple') . ' ' . get_query_var('paged');
            if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
                echo ')';
        }

        echo '</div>';
    }
}

add_action('ripple_breadcrumb', 'ripple_breadcrumb_cb');

/** Is home page with set to display latest posts and parallax is enabled * */

/** Slider Modification **/

    function ripple_slider_bx() {
        $enabled_sections = ripple_get_parallax_sections();
        $next_section = '';
        
        if(!empty($enabled_sections)) {
            $next_section = '#'.$enabled_sections[0]['id'];    
        }
        
        $enable_slider_overlay = esc_attr(get_theme_mod('ripple_enable_slider_overlay', ''));
        $slider_readmore_text = esc_attr(get_theme_mod('ripple_slider_readmore_text', 'Call To Action'));
        $slider_category = esc_attr(get_theme_mod('ripple_slider_category'));
        $sl_args = array('post_type' => 'post', 'posts_per_page' => 5, 'cat' => $slider_category );
        $sl_query = new WP_Query($sl_args);
        
        if($slider_category) :
            if($sl_query->have_posts()) :
            ?>
                <section id="plx-slider-section">
                    <ul class='main-slider'>
                        <?php 
                            while($sl_query->have_posts()) : $sl_query->the_post();
                            $img = wp_get_attachment_image_src(get_post_thumbnail_id(), 'ripple-slider-image-size');
                            $img_src = $img[0];
                        ?>
                        <li class="slide">
                            <?php if ($enable_slider_overlay == 1) : ?>
                                <div class="slider-overlay1"></div>
                            <?php endif; ?>
                            <img src="<?php echo esc_url($img_src); ?>" />                            
                            <div class="slide-caption">
                                <div class="container">
                                    <span class="caption-title"><?php the_title(); ?></span>
                                    <span class="caption-descr"><?php the_content(); ?></span>
                                </div>
                            </div>
                        </li>
                        <?php endwhile; ?>
                    </ul>
                    <?php if (is_page_template('tpl-home.php')) : ?>
                    
                    <div class="slider-down-btn">
                        <span class="next-page">
                            <a href="<?php echo esc_attr($next_section); ?>"><img src="<?php echo get_template_directory_uri().'/images/yellow-arrow.png'; ?>" /></a>
                        </span>
                    </div>
                    <?php endif; ?>
                </section>
            <?php
            endif;
        endif;
    }
    add_action('ripple_slider', 'ripple_slider_bx');
    /** Extra Functions **/
     function ripple_get_parallax_sections() {
        $sections = array('feature', 'progress', 'portfolio', 'cta', 'about', 'testimonial', 'blog', 'cl_logo', 'contact');
        $enabled_section = array();
        foreach ($sections as $section) :
            if (get_theme_mod('ripple_'.$section . '_section_enable') == 1) :
                $enabled_section[] = array(
                    'id' => 'plx_' . $section . '_section',
                    'menu_text' => get_theme_mod('ripple_'.$section . '_section_menu_title',''),
                    'section' => $section,
                );
            endif;
        endforeach;
        return $enabled_section;
    }
    function ripple_sanitize_bradcrumb($input){
    $all_tags = array(
        'a'=>array(
            'href'=>array()
        )
     );
    return wp_kses($input,$all_tags);
    
}
    ?>