<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Ripple
 */
if ( ! function_exists( 'ripple_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function ripple_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'ripple' ) );
		if ( $categories_list && ripple_categorized_blog() ) {
		  if(get_theme_mod('posted_in_text') == false) : 
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'ripple' ) . '</span>', $categories_list ); // WPCS: XSS OK.
          else :
            printf( '<span class="cat-links">' . esc_html__( get_theme_mod('posted_in_text').' %1$s', 'ripple' ) . '</span>', $categories_list ); // WPCS: XSS OK.
          endif;
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'ripple' ) );
		if ( $tags_list ) {
		  if(get_theme_mod('tagged_text') == false) :
            printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'ripple' ) . '</span>', $tags_list ); // WPCS: XSS OK.
          else :
            printf( '<span class="tags-links">' . esc_html__( get_theme_mod('tagged_text').' %1$s', 'ripple' ) . '</span>', $tags_list ); // WPCS: XSS OK.
          endif;
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'ripple' ), esc_html__( '1 Comment', 'ripple' ), esc_html__( '% Comments', 'ripple' ) );
		echo '</span>';
	}

	edit_post_link( esc_html__( 'Edit', 'ripple' ), '<span class="edit-link">', '</span>' );
}
endif;

function ripple_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'ripple_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'ripple_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so ripple_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so ripple_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in ripple_categorized_blog.
 */
function ripple_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'ripple_categories' );
}
add_action( 'edit_category', 'ripple_category_transient_flusher' );
add_action( 'save_post',     'ripple_category_transient_flusher' );
